# gulp-email-builder-min

Uses [Email Builder Core Min](https://www.npmjs.com/package/email-builder-core-min) to inline css into HTML tags and send test emails to yourself.

Example:
```html
<!DOCTYPE html>
<html>
<head>
  <!-- styles will be inlined -->
  <link rel="stylesheet" type="text/css" href="../css/styles.css">

  <!-- styles will be embedded -->
  <link rel="stylesheet" type="text/css" href="../css/otherStyles.css" data-embed>

  <!-- link tag will be preserved and styles will not be inlined or embedded -->
  <link href='http://fonts.googleapis.com/css?family=Open+Sans' rel='stylesheet' type='text/css' data-embed-ignore>

  <!-- styles will be inlined -->
  <style>
    p { color: red; }
  </style>

  <!-- styles will be embedded -->
  <style data-embed>
    h1 { color: black; }
  </style>
</head>
<body>
  <h1>Heading</h1>
  <p>Body</p>
</body>
</html>
```

You can see an example setups below
- [example](https://github.com/Email-builder/email-builder-example)
- [rwdemail](https://github.com/iDVB/rwdemail) by [iDVB](https://github.com/iDVB)

## Getting Started

Install this gulp plugin next to your project's gulpfile  with: `npm install gulp-email-builder-min`

Then add this line to your project's `gulp.js` gulp:

```javascript
const emailBuilder = require('gulp-email-builder-min');
```

[gulp]: http://gulpjs.com/
[getting_started]: https://github.com/gulpjs/gulp/blob/master/docs/getting-started.md



## Documentation

Place this in your gulp file.
```javascript
  gulp.task('emailBuilder', () => {
    return gulp.src(['./example/html/*.html'])
      .pipe(emailBuilder(options).build())
      .pipe(gulp.dest('./example/dist/'));
  });
```

## Other available methods

Besides the main `emailBuilder(options).build()` function, the `email-builder-core` methods are exposed so users can use them on an individual basis.

- emailBuilder(options).inlineCss()
- emailBuilder(options).sendEmailTest()

**Example**
```javascript
...
.pipe(emailBuilder(options).sendEmailTest())
...
```

## Options
View [Email Builder Core Min Options](https://www.npmjs.com/package/email-builder-core-min#options) for all available options.

## Complete Example

```javascript
const EmailBuilder = require('gulp-email-builder');

const options = { encodeSpecialChars: true }
const builder = EmailBuilder(options);

gulp.task('emailBuilder', () => {
  return gulp.src(['./example/html/*.html'])
    .pipe(builder.build())
    .pipe(gulp.dest('./example/dist/'));
});

```

### Thanks

The original Email Builder Core Team:

Jeremy Peter (https://github.com/jeremypeter)

Steve Miller (http://www.stevenjohnmiller.com.au)

## License
[MIT](https://github.com/Email-builder/gulp-email-builder/blob/master/LICENSE)
