const del = require('del');
const gulp = require('gulp');
const jshint = require('gulp-jshint');
const mocha = require('gulp-mocha');
const runSequence = require('run-sequence');
const emailBuilder = require('./lib/emailBuilder');

gulp.task('clean', (cb) => {
  return del([
    './example/dist',
    './reports'
  ], cb);
});

gulp.task('emailBuilder', () => {

  return gulp.src(['./example/html/*.html'])
    .pipe(emailBuilder().build())
    .pipe(gulp.dest('./example/dist/'));
});

// Send to Email
gulp.task('sendEmail', () => {
  return gulp.src(['./example/html/email.html'])
    .pipe(emailBuilder({
      emailTest: {
        email : process.env.GMAIL_USER,
        subject : 'Email Subject',
        nodemailer: {
          transporter: {
            service: 'gmail',
            auth: {
              user: process.env.GMAIL_USER,
              pass: process.env.GMAIL_PASS
            }
          }
        }
      }
    }));
});

gulp.task('mochaTest', () =>  {
  return gulp.src('./test/*_test.js', { read: false })
    .pipe(mocha({ reporter: 'spec' }));
});

gulp.task('lint', () =>  {
  return gulp.src(['./lib/*.js', 'gulpfile.js'])
    .pipe(jshint())
    .pipe(jshint.reporter('jshint-stylish'));
});

gulp.task('test', gulp.series('clean', 'lint', 'emailBuilder', 'mochaTest'));
