const expect = require('chai').expect;
const sinon =  require('sinon');
const builder = require('../lib/emailBuilder');
const fs = require('fs');
const File = require('vinyl');
const path = require('path');
const core = require('email-builder-core-min');
const Promise = require('bluebird');
const gutil = require('gulp-util');

function getFile(filePath) {
    return new File({
        path: path.resolve(filePath),
        cwd: './test/',
        base: path.dirname(filePath),
        contents: fs.readFileSync(filePath)
    });
}

function getPromise(html) {
  return Promise.resolve(html)
}

describe('gulp-email-builder-min', () => {
  let stream;
  let stub;
  let spy;
  let cwd = process.cwd();
  let src = fs.readFileSync(cwd + '/test/expected/email.html');
  const options = {
    emailTest : {
      email : 'yourEmail@email.com',
      subject : 'Email Subject'
    },
  }

  it('should inline css', (done) => {

    spy = sinon.spy(core.prototype, 'inlineCss');

    stream = builder({}).build();
    stream.write(getFile(cwd + '/example/html/email.html'));
    stream.once('data', (file) => {
      expect(file.isBuffer()).to.be.true;
      expect(file.contents.toString()).to.equal(src.toString());
      expect(spy.called).to.be.true;
      done();
    });

  });

  it('should call sendEmailTest if `emailTest` option defined', (done) => {

    stub =  sinon.stub(core.prototype, 'sendEmailTest', getPromise);

    stream = builder(options).sendEmailTest();
    stream.write(getFile(cwd + '/example/html/email.html'));
    stream.once('data', (file) => {
      expect(stub.called).to.be.true;
      done();
    });

  });

  it('should throw error if `sendEmailTest` is called without options', () => {
    expect(() => { builder({}).sendEmailTest() }).to.throw(Error);
  });

});